Tento návod popisuje, jak pracovat s oddělenými repozitáři na GitHubu a Gitea, aby bylo možné provádět úpravy a změny na Gitea bez ovlivnění repozitáře na GitHubu, dokud nejsi připraven změny pushnout.

## 1. Vytvoření repozitářů

### 1.1 Fork původního projektu na GitHubu

1. Přejdi na GitHub a forkuj původní repozitář.
2. Tento fork bude sloužit k synchronizaci s upstream a sledování změn v původním projektu.

### 1.2 Vytvoření nového repozitáře na Gitea

1. Vytvoř nový repozitář na Gitea.
2. Tento repozitář bude sloužit pro tvé vlastní úpravy, včetně README a lokalizace.

## 2. Klonování a nastavení vzdálených repozitářů

### 2.1 Klonování forknutého repozitáře z GitHubu

```bash
git clone git@github.com:tvuj-ucet/phanpy-cz.git
cd phanpy-cz
```
### 2.2 Přidání upstream repozitáře (původního projektu)

```bash
git remote add upstream git@github.com:cheeaun/phanpy.git
```

### 2.3 Přidání vzdáleného repozitáře na Gitea

```bash
git remote add gitea ssh://git@git.arch-linux.cz:29418/Archos/phanpy-cz.git
```
## 3. Práce na Gitea

### 3.1 Vytvoření a přepnutí na novou větev na Gitea

```bash
git checkout -b localization
```

### 3.2 Proveď změny a commitni je

```bash
subl README.md  # nebo jiný editor
git add README.md
git commit -m "Updated README for Czech localization"
```
### 3.3 Pushni změny do Gitea

```bash
git push gitea localization
```

### 3.4 Sloučení změn do hlavní větve na Gitea
1. Přepni se na hlavní větev

```bash
git checkout main
```
2. Slouč změny z větve localization


```bash
git merge localization
```
3. Pushni změny do hlavního repozitáře na Gitea
```bash
git push gitea main
```
## Možnost 2: Použití Pull Requestu (PR)

### 3.1 Vytvoření a přepnutí na novou větev na Gitea 
```bash
git checkout -b localization
```
### 3.2 Proveď změny a commitni je
```bash
subl README.md  # nebo jiný editor
git add README.md
git commit -m "WIP: Updated README for Czech localization"
```

### 3.3 Pushni změny do Gitea

```bash
git push gitea localization
```
### 3.4 Vytvoření Pull Requestu na Gitea

1. Otevři svůj repozitář na Gitea.
2. Klikni na "New Pull Request".
3. Vyber větev localization a požádej o sloučení změn do hlavní větve.
4. V názvu PR použij předponu "WIP" (např. "WIP: Updated README for Czech localization").


## 4. Synchronizace změn z Gitea na GitHub

### 4.1 Push změn z Gitea na GitHub

 1.  Přepni se na hlavní větev (pokud nejsi)

```bash
git checkout main
```

2. Pushni změny do GitHubu

```bash 
git push origin main
```
## 5. Aktualizace z upstream repozitáře
### 5.1 Synchronizace změn z upstream

1. Přepni se na hlavní větev

```bash
git checkout main
```

2. Stáhni nejnovější změny z upstream

```bash
git fetch upstream
```
3. Slouč změny z upstream do hlavní větve

```bash
git merge upstream/main
```
### 5.2 Push změn na GitHub a Gitea

1. Pushni změny do GitHubu

```bash
git push origin main
```
2. Pushni změny do Gitea

```bash
git push gitea main
```
## Shrnutí

- Gitea repozitář: Můžeš provádět veškeré změny, slučování větví a další úpravy.
- GitHub repozitář: Bude aktualizován pouze tehdy, když explicitně pushneš změny z Gitea na GitHub.

Tímto způsobem můžeš mít plnou kontrolu nad změnami a správou projektu na Gitea, aniž bys ovlivnil GitHub repozitář, dokud nebudeš připraven změny pushnout.

## Poznámky

- Při práci na lokalizaci nebo jiných úpravách můžeš volně experimentovat na Gitea.
- Když budeš připraven, můžeš sloučit změny do hlavní větve na Gitea a poté pushnout do GitHubu.